==> chunky_files-0.3.0.tar.gz: chunky_files-0.3.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.3.0] - TBD

### Added
- Language-aware chunkers for Python, Markdown, JSON/YAML, and plain text with metadata-rich outputs.
- Registry bootstrap that pre-registers the built-in chunkers for common extensions.
- Unit tests covering the new chunkers and regression coverage for the sliding-window fallback.

## [0.2.2] - 2025-09-30

### Fixed
- Pinned the release workflow to `pypa/gh-action-pypi-publish@release/v1` and added a `twine check` gate, eliminating spurious "missing Name/Version" errors during automated publishes.
- Corrected the Sphinx intersphinx configuration so Read the Docs builds resolve the Python inventory without manual tweaks.

## [0.2.1] - 2025-09-30

### Changed
- Renamed the published distribution to `chunky-files` and refreshed packaging metadata for the new name.

### Fixed
- Ensured `pyproject.toml` ships in the sdist include list to keep build metadata intact across platforms.

## [0.2.0] - TBD
### Added
- Changelog (`CHANGELOG.md`; this file).
- Release process section added to the existing `README.md`
- `PYPI_TOKEN`, `TEST_PYPI_TOKEN`, and `CODECOV_TOKEN` added to github secrets
- `.env` and other common evironment file name added to the `.gitignore` for token security. 
### Changes
- Release workflow updated to have matching secrets name.
### Fixes
- Updated dependencies and improve type hints in codebase (ruff compliance).
- Update build tooling installation in release .
- Included pyproject.toml in sdist build targets.

## [0.1.0] - 2025-09-30
### Added
- Initial project scaffolding with Hatchling build system and CI/release workflows.
- Core chunking data models (`Document`, `Chunk`, `ChunkerConfig`).
- Sliding-window fallback chunker with metadata-rich outputs.
- `ChunkPipeline` orchestration, registry, and filesystem loader.
- Sphinx documentation skeleton and Read the Docs configuration.
- Pytest and Ruff tooling with baseline tests for the sliding-window chunker.

==> chunky_files-0.4.1.tar.gz: chunky_files-0.4.1/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.4.1] - TBD

## [0.4.0] - 2025-10-03

### Added
- Language-aware chunkers for Python, Markdown, JSON/YAML, plain text, Fortran, and Tree-sitter powered C/C++/HTML/Bash support.
- Optional `tree` extra now installs `tree-sitter==0.20.1` plus the bundled grammars so pre-built parsers load reliably.

## [0.3.0] - 2025-10-02

- Registry bootstrap that pre-registers the built-in chunkers for common extensions.
- Unit tests covering the new chunkers and regression coverage for the sliding-window fallback.

## [0.2.2] - 2025-09-30
### Fixed
- Pinned the release workflow to `pypa/gh-action-pypi-publish@release/v1` and added a `twine check` gate, eliminating spurious "missing Name/Version" errors during automated publishes.
- Corrected the Sphinx intersphinx configuration so Read the Docs builds resolve the Python inventory without manual tweaks.

## [0.2.1] - 2025-09-30

### Changed
- Renamed the published distribution to `chunky-files` and refreshed packaging metadata for the new name.

### Fixed
- Ensured `pyproject.toml` ships in the sdist include list to keep build metadata intact across platforms.

## [0.2.0] - TBD
### Added
- Changelog (`CHANGELOG.md`; this file).
- Release process section added to the existing `README.md`
- `PYPI_TOKEN`, `TEST_PYPI_TOKEN`, and `CODECOV_TOKEN` added to github secrets
- `.env` and other common evironment file name added to the `.gitignore` for token security. 
### Changes
- Release workflow updated to have matching secrets name.
### Fixes
- Updated dependencies and improve type hints in codebase (ruff compliance).
- Update build tooling installation in release .
- Included pyproject.toml in sdist build targets.

## [0.1.0] - 2025-09-30
### Added
- Initial project scaffolding with Hatchling build system and CI/release workflows.
- Core chunking data models (`Document`, `Chunk`, `ChunkerConfig`).
- Sliding-window fallback chunker with metadata-rich outputs.
- `ChunkPipeline` orchestration, registry, and filesystem loader.
- Sphinx documentation skeleton and Read the Docs configuration.
- Pytest and Ruff tooling with baseline tests for the sliding-window chunker.
